==> fr.opensagres.xdocreport.itext.extension-0.9.1-sources.jar: fr/opensagres/xdocreport/itext/extension/MasterPageHeaderFooter.java <==
/**
 * Copyright (C) 2011 Angelo Zerr <angelo.zerr@gmail.com> and Pascal Leclercq <pascal.leclercq@gmail.com>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free  of charge, to any person obtaining
 * a  copy  of this  software  and  associated  documentation files  (the
 * "Software"), to  deal in  the Software without  restriction, including
 * without limitation  the rights to  use, copy, modify,  merge, publish,
 * distribute,  sublicense, and/or sell  copies of  the Software,  and to
 * permit persons to whom the Software  is furnished to do so, subject to
 * the following conditions:
 *
 * The  above  copyright  notice  and  this permission  notice  shall  be
 * included in all copies or substantial portions of the Software.
 *
 * THE  SOFTWARE IS  PROVIDED  "AS  IS", WITHOUT  WARRANTY  OF ANY  KIND,
 * EXPRESS OR  IMPLIED, INCLUDING  BUT NOT LIMITED  TO THE  WARRANTIES OF
 * MERCHANTABILITY,    FITNESS    FOR    A   PARTICULAR    PURPOSE    AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE,  ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package fr.opensagres.xdocreport.itext.extension;

import com.lowagie.text.Rectangle;
import com.lowagie.text.pdf.PdfPCell;


public class MasterPageHeaderFooter extends ExtendedPdfPTable implements IMasterPageHeaderFooter {

	private final PdfPCell tableCell;

	public MasterPageHeaderFooter() {
		super(1);
		super.setTotalWidth(1000);
		super.setWidthPercentage(100f);
		tableCell = new ExtendedPdfPCell();
		tableCell.disableBorderSide(Rectangle.BOX);				
	}
	
	public PdfPCell getTableCell() {
		return tableCell;
	}
	
	public void flush() {
		super.addCell(tableCell);		
	}
}

==> fr.opensagres.xdocreport.itext.extension-1.0.4-sources.jar: fr/opensagres/xdocreport/itext/extension/MasterPageHeaderFooter.java <==
/**
 * Copyright (C) 2011-2012 The XDocReport Team <xdocreport@googlegroups.com>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free  of charge, to any person obtaining
 * a  copy  of this  software  and  associated  documentation files  (the
 * "Software"), to  deal in  the Software without  restriction, including
 * without limitation  the rights to  use, copy, modify,  merge, publish,
 * distribute,  sublicense, and/or sell  copies of  the Software,  and to
 * permit persons to whom the Software  is furnished to do so, subject to
 * the following conditions:
 *
 * The  above  copyright  notice  and  this permission  notice  shall  be
 * included in all copies or substantial portions of the Software.
 *
 * THE  SOFTWARE IS  PROVIDED  "AS  IS", WITHOUT  WARRANTY  OF ANY  KIND,
 * EXPRESS OR  IMPLIED, INCLUDING  BUT NOT LIMITED  TO THE  WARRANTIES OF
 * MERCHANTABILITY,    FITNESS    FOR    A   PARTICULAR    PURPOSE    AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE,  ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package fr.opensagres.xdocreport.itext.extension;

import com.lowagie.text.Rectangle;
import com.lowagie.text.pdf.PdfPCell;

public class MasterPageHeaderFooter
    extends ExtendedPdfPTable
    implements IMasterPageHeaderFooter
{

    private final PdfPCell tableCell;

    public MasterPageHeaderFooter()
    {
        super( 1 );
        super.setTotalWidth( 1000 );
        super.setWidthPercentage( 100f );
        tableCell = new ExtendedPdfPCell();
        tableCell.disableBorderSide( Rectangle.BOX );
    }

    public PdfPCell getTableCell()
    {
        return tableCell;
    }

    public void flush()
    {
        super.addCell( tableCell );
    }
}
